@@ -8,11 +8,13 @@
 //!
 //! Check [`Match`]'s documentation for examples.
 use crate::{Match, Request};
+use assert_json_diff::{assert_json_matches_no_panic, CompareMode};
 use http_types::headers::{HeaderName, HeaderValue, HeaderValues};
 use http_types::Method;
 use log::debug;
 use regex::Regex;
 use serde::Serialize;
+use serde_json::Value;
 use std::convert::TryInto;
 use std::str;
 
@@ -503,34 +505,38 @@ impl Match for HeaderExistsMatcher {
 ///     assert_eq!(status, 200);
 /// }
 /// ```
-pub struct BodyExactMatcher(Vec<u8>);
+pub struct BodyExactMatcher(Body);
+
+#[derive(Debug)]
+enum Body {
+    Bytes(Vec<u8>),
+    Json(Value),
+}
 
 impl BodyExactMatcher {
     /// Specify the expected body as a string.
     pub fn string<T: Into<String>>(body: T) -> Self {
         let body = body.into();
-        Self(body.as_bytes().into())
+        Self(Body::Bytes(body.into_bytes()))
     }
 
     /// Specify the expected body as a vector of bytes.
     pub fn bytes<T: Into<Vec<u8>>>(body: T) -> Self {
         let body = body.into();
-        Self(body)
+        Self(Body::Bytes(body))
     }
 
     /// Specify something JSON-serializable as the expected body.
     pub fn json<T: Serialize>(body: T) -> Self {
-        let body = serde_json::to_vec(&body).expect("Failed to serialise body");
-        Self(body)
+        let bytes = serde_json::to_vec(&body).expect("Failed to serialize JSON body");
+        Self::json_string(bytes)
     }
-}
 
-/// Shorthand for [`BodyExactMatcher::json`].
-pub fn body_json<T>(body: T) -> BodyExactMatcher
-where
-    T: Serialize,
-{
-    BodyExactMatcher::json(body)
+    /// Specify a JSON string as the expected body.
+    pub fn json_string(body: impl AsRef<[u8]>) -> Self {
+        let body = serde_json::from_slice(body.as_ref()).expect("Failed to parse JSON string");
+        Self(Body::Json(body))
+    }
 }
 
 /// Shorthand for [`BodyExactMatcher::string`].
@@ -549,9 +555,31 @@ where
     BodyExactMatcher::bytes(body)
 }
 
+/// Shorthand for [`BodyExactMatcher::json`].
+pub fn body_json<T>(body: T) -> BodyExactMatcher
+where
+    T: Serialize,
+{
+    BodyExactMatcher::json(body)
+}
+
+/// Shorthand for [`BodyExactMatcher::json_string`].
+pub fn body_json_string(body: impl AsRef<[u8]>) -> BodyExactMatcher {
+    BodyExactMatcher::json_string(body)
+}
+
 impl Match for BodyExactMatcher {
     fn matches(&self, request: &Request) -> bool {
-        request.body == self.0
+        match &self.0 {
+            Body::Bytes(bytes) => request.body == *bytes,
+            Body::Json(json) => {
+                if let Ok(body) = serde_json::from_slice::<Value>(&request.body) {
+                    body == *json
+                } else {
+                    false
+                }
+            }
+        }
     }
 }
 
@@ -626,6 +654,78 @@ impl Match for BodyContainsMatcher {
     }
 }
 
+#[derive(Debug)]
+/// Match part JSON body of a request.
+///
+/// ### Example:
+/// ```rust
+/// use wiremock::{MockServer, Mock, ResponseTemplate};
+/// use wiremock::matchers::body_partial_json;
+/// use serde_json::json;
+///
+/// #[async_std::main]
+/// async fn main() {
+///     // Arrange
+///     let mock_server = MockServer::start().await;
+///
+///     let expected_body = json!({
+///         "hello": "world!"
+///     });
+///     Mock::given(body_partial_json(&expected_body))
+///         .respond_with(ResponseTemplate::new(200))
+///         .mount(&mock_server)
+///         .await;
+///
+///     // Act
+///     let body = json!({
+///         "hello": "world!",
+///         "foo": "bar"
+///     });
+///     let status = surf::post(&mock_server.uri())
+///         .body(body)
+///         .await
+///         .unwrap()
+///         .status();
+///
+///     // Assert
+///     assert_eq!(status, 200);
+/// }
+/// ```
+pub struct BodyPartialJsonMatcher(Value);
+
+impl BodyPartialJsonMatcher {
+    /// Specify the part of the body that should be matched as a JSON value.
+    pub fn json<T: Serialize>(body: T) -> Self {
+        Self(serde_json::to_value(body).expect("Can't serialize to JSON"))
+    }
+
+    /// Specify the part of the body that should be matched as a string.
+    pub fn json_string(body: impl AsRef<str>) -> Self {
+        Self(serde_json::from_str(body.as_ref()).expect("Can't deserialize JSON"))
+    }
+}
+
+/// Shorthand for [`BodyPartialJsonMatcher::json`].
+pub fn body_partial_json<T: Serialize>(body: T) -> BodyPartialJsonMatcher {
+    BodyPartialJsonMatcher::json(body)
+}
+
+/// Shorthand for [`BodyPartialJsonMatcher::json_string`].
+pub fn body_partial_json_string(body: impl AsRef<str>) -> BodyPartialJsonMatcher {
+    BodyPartialJsonMatcher::json_string(body)
+}
+
+impl Match for BodyPartialJsonMatcher {
+    fn matches(&self, request: &Request) -> bool {
+        if let Ok(body) = serde_json::from_slice::<Value>(&request.body) {
+            let config = assert_json_diff::Config::new(CompareMode::Inclusive);
+            assert_json_matches_no_panic(&body, &self.0, config).is_ok()
+        } else {
+            false
+        }
+    }
+}
+
 #[derive(Debug)]
 /// Match **exactly** the query parameter of a request.
 ///
